import deepmerge from 'deepmerge';
import { DrupalJsonApiParams } from 'drupal-jsonapi-params';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

const paramBuilder = new DrupalJsonApiParams();
function withPagination(params, opts) {
  var _opts, _opts$context;

  if (!opts) {
    return params;
  }

  if ((_opts = opts) == null ? void 0 : (_opts$context = _opts.context) == null ? void 0 : _opts$context.query) {
    opts = _extends({}, opts, opts.context.query);
  }

  if (typeof opts.page !== undefined && typeof opts.limit !== undefined) {
    params.addPageLimit(opts.limit).addPageOffset(opts.page * opts.limit);
  }

  return params;
}
function massageRouteQuery(query) {
  if (!query) {
    return {};
  } // Remove slug keys from query.


  Object.keys(query).forEach(key => {
    if (key.startsWith("slug")) {
      delete query[key];
    }
  });

  if (query == null ? void 0 : query.page) {
    query.page = parseInt(`${query.page}`);
  }

  if (query == null ? void 0 : query.limit) {
    query.limit = parseInt(`${query.limit}`);
  }

  return query;
}
function createQueries(queries) {
  return {
    getDataIds: () => {
      const ids = [];

      for (const id in queries) {
        if (typeof queries[id]["data"] !== "undefined") {
          ids.push(id);
        }
      }

      return ids;
    },
    getIds: () => {
      const ids = [];

      for (const id in queries) {
        ids.push(id);
      }

      return ids;
    },
    getParams: (id = null, opts = null) => {
      if (typeof window !== "undefined") {
        throw new Error("You should not call getQueryParams on the client. This is a server-only call.");
      }

      if (!id) {
        return paramBuilder.clear();
      }

      const query = queries == null ? void 0 : queries[id];

      if (!query) {
        throw new Error(`Query with id '${id}' not found.`);
      }

      if (!query["params"]) {
        throw new Error(`No params defined for query with id '${id}'.`);
      } // eslint-disable-next-line @typescript-eslint/no-explicit-any


      return query["params"](opts);
    },
    getData: async (id, opts = null) => {
      if (typeof window !== "undefined") {
        throw new Error("You should not call getQueryData on the client. This is a server-only call.");
      }

      const query = queries == null ? void 0 : queries[id];

      if (!query) {
        throw new Error(`Query with id '${id}' not found.`);
      }

      if (!query["data"]) {
        throw new Error(`No data defined for query with id '${id}'.`);
      }

      opts = massageRouteQuery(opts);

      if (typeof query["defaultOpts"] !== undefined && typeof opts !== undefined) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        opts = deepmerge(query["defaultOpts"], opts);
      } // eslint-disable-next-line @typescript-eslint/no-explicit-any


      return await query["data"](opts);
    }
  };
}

export { createQueries, massageRouteQuery, withPagination };
//# sourceMappingURL=index.modern.js.map
